@@ -53,8 +53,6 @@ class Controller(object):
         project_creator.create_root_folder(self._args.project_path)
         project_creator.create_subfolders(self._paths.required_folders())
         project_creator.create_version_file(self._paths.version_path, version)
-        sys.stdout.write("Created folder \"%s\" and required subfolders.\n" % (
-            self._args.project_path))
         sys.stdout.write("Created folder \"%s\" and required subfolders.\n" % (
                 self._args.project_path))
         sys.stdout.write("Please copy read files into folder \"%s\" and "
@@ -93,6 +91,11 @@ class Controller(object):
             self._paths.primary_read_aligner_sam_paths,
             self._paths.primary_read_aligner_bam_prefix_paths,
             self._paths.primary_read_aligner_bam_paths)
+        self._generate_read_alignment_stats(
+            self._lib_names,
+            self._paths.primary_read_aligner_bam_paths,
+            self._paths.unaligned_reads_paths,
+            self._paths.primary_read_aligner_stats_path)
         final_unaligned_reads_paths = self._paths.unaligned_reads_paths
         if self._args.realign is True:
             self._run_realigner_and_process_alignments()
